
===========================================
Attributes and Methods in `LexicalRichness`
===========================================

This addendum exposes the underlying `lexicalrichness` measures from attributes and methods in the `LexicalRichness` class.

**TTR:** Type-Token Ratio (*Chotlos 1944, Templin 1957*)

.. autofunction:: lexicalrichness.LexicalRichness.ttr
----


**RTTR:** Root Type-Token Ratio (*Guiraud 1954, 1960*)]

.. autofunction:: lexicalrichness.LexicalRichness.rttr
----


**CTTR:** Corrected Type-Token Ratio (*Carrol 1964*)

.. autofunction:: lexicalrichness.LexicalRichness.cttr
----


**Herdan**: Herdan's C (*Herdan 1960, 1964*)

.. autofunction:: lexicalrichness.LexicalRichness.Herdan

----

**Summer**: Summer (*Summer 1966*)

.. autofunction:: lexicalrichness.LexicalRichness.Summer
----


**Dugast**: Dugast (*Dugast 1978*)

.. autofunction:: lexicalrichness.LexicalRichness.Dugast
----


**Maas**: Maas (*Maas 1972*)

.. autofunction:: lexicalrichness.LexicalRichness.Maas
----


**msttr**: Mean Segmental Type-Token Ratio (*Johnson 1944*)

.. autofunction:: lexicalrichness.LexicalRichness.msttr
----


**mattr**: Moving Average Type-Token Ratio (*Covington 2007, Covington and McFall 2010*)

.. autofunction:: lexicalrichness.LexicalRichness.mattr
----


**mtld**: Measure of Textual Lexical Diversity (*McCarthy 2005, McCarthy and Jarvis 2010*)

.. autofunction:: lexicalrichness.LexicalRichness.mtld
----


**hdd**: Hypergeometric Distribution Diversity (*McCarthy and Jarvis 2007*)

.. autofunction:: lexicalrichness.LexicalRichness.hdd
----


**vocd**: vod-D (*Mckee, Malvern, and Richards 2010*)

.. autofunction:: lexicalrichness.LexicalRichness.vocd


----

**Helper**: lexicalrichness.segment_generator

.. autofunction:: lexicalrichness.segment_generator

**Helper**: lexicalrichness.list_sliding_window

.. autofunction:: lexicalrichness.list_sliding_window

